@@ -2,21 +2,52 @@ from typing import *
 
 
 class Categorical:
-    def __init__(
-        self,
+    @overload
+    @classmethod
+    def from_codes(
+        cls,
         /,
-        values: Union[
-            List[Union[str, int]],
-            pandas.core.indexes.datetimes.DatetimeIndex,
-            pandas.core.indexes.numeric.Float64Index,
-            pandas.core.indexes.base.Index,
-        ],
-        categories: Union[None, pandas.core.indexes.base.Index] = ...,
-        ordered: bool = ...,
+        codes: numpy.ndarray,
+        categories: List[Literal["2014-01-03.csv", "2014-01-02.csv", "2014-01-01.csv"]],
     ):
         """
-        usage.dask: 10
-        usage.sklearn: 1
+        usage.dask: 1
+        """
+        ...
+
+    @overload
+    @classmethod
+    def from_codes(cls, /, codes: numpy.ndarray, categories: List[str]):
+        """
+        usage.dask: 1
+        """
+        ...
+
+    @overload
+    @classmethod
+    def from_codes(
+        cls,
+        /,
+        codes: List[int],
+        categories: pandas.core.indexes.base.Index,
+        ordered: bool,
+    ):
+        """
+        usage.dask: 1
+        """
+        ...
+
+    @overload
+    @classmethod
+    def from_codes(
+        cls,
+        /,
+        codes: numpy.ndarray,
+        categories: pandas.core.indexes.base.Index,
+        ordered: bool,
+    ):
+        """
+        usage.dask: 2
         """
         ...
 
@@ -26,6 +57,7 @@ class Categorical:
         /,
         codes: Union[numpy.ndarray, List[int]],
         categories: Union[pandas.core.indexes.base.Index, List[str]],
+        ordered: bool = ...,
     ):
         """
         usage.dask: 5
@@ -47,6 +79,27 @@ class Categorical:
     # usage.dask: 1
     ordered: object
 
+    @overload
+    def __contains__(self, _0: Literal["2014-01-01.csv"], /):
+        """
+        usage.dask: 2
+        """
+        ...
+
+    @overload
+    def __contains__(self, _0: Literal["2014-01-02.csv"], /):
+        """
+        usage.dask: 2
+        """
+        ...
+
+    @overload
+    def __contains__(self, _0: Literal["2014-01-03.csv"], /):
+        """
+        usage.dask: 2
+        """
+        ...
+
     def __contains__(
         self, _0: Literal["2014-01-03.csv", "2014-01-02.csv", "2014-01-01.csv"], /
     ):
@@ -61,12 +114,6 @@ class Categorical:
         """
         ...
 
-    def sort_values(self, /):
-        """
-        usage.dask: 1
-        """
-        ...
-
 
 class CategoricalAccessor:
 
@@ -115,6 +162,20 @@ class CategoricalAccessor:
         """
         ...
 
+    @overload
+    def set_categories(self, /, *args: Literal["v", "t"]):
+        """
+        usage.dask: 8
+        """
+        ...
+
+    @overload
+    def set_categories(self, /):
+        """
+        usage.dask: 1
+        """
+        ...
+
     def set_categories(self, /, *args: Literal["v", "t"]):
         """
         usage.dask: 9
