@@ -2,27 +2,6 @@ from typing import *
 
 
 class CategoricalIndex:
-    def __init__(
-        self,
-        /,
-        data: Union[
-            pandas.core.arrays.categorical.Categorical,
-            pandas.core.indexes.base.Index,
-            List[Literal["B", "A", "xyx"]],
-        ],
-        name: Literal["b", "foo", "A", "B", "C"],
-        categories: Union[
-            List[str],
-            pandas.core.indexes.numeric.Float64Index,
-            pandas.core.indexes.base.Index,
-            pandas.core.indexes.datetimes.DatetimeIndex,
-        ] = ...,
-        ordered: bool = ...,
-    ):
-        """
-        usage.dask: 12
-        """
-        ...
 
     # usage.dask: 1
     __module__: ClassVar[object]
@@ -63,12 +42,40 @@ class CategoricalIndex:
     # usage.xarray: 1
     values: object
 
+    @overload
+    def __contains__(self, _0: Literal["divisions"], /):
+        """
+        usage.dask: 1
+        """
+        ...
+
+    @overload
+    def __contains__(self, _0: Literal["dtype"], /):
+        """
+        usage.dask: 1
+        """
+        ...
+
     def __contains__(self, _0: Literal["dtype", "divisions"], /):
         """
         usage.dask: 2
         """
         ...
 
+    @overload
+    def __eq__(self, _0: numpy.ndarray, /):
+        """
+        usage.pandas: 4
+        """
+        ...
+
+    @overload
+    def __eq__(self, _0: pandas.core.indexes.category.CategoricalIndex, /):
+        """
+        usage.dask: 2
+        """
+        ...
+
     def __eq__(
         self, _0: Union[pandas.core.indexes.category.CategoricalIndex, numpy.ndarray], /
     ):
@@ -78,6 +85,42 @@ class CategoricalIndex:
         """
         ...
 
+    @overload
+    def __getitem__(self, _0: slice[None, int, None], /):
+        """
+        usage.xarray: 1
+        """
+        ...
+
+    @overload
+    def __getitem__(self, _0: slice[int, None, int], /):
+        """
+        usage.xarray: 1
+        """
+        ...
+
+    @overload
+    def __getitem__(self, _0: int, /):
+        """
+        usage.dask: 4
+        usage.xarray: 1
+        """
+        ...
+
+    @overload
+    def __getitem__(self, _0: numpy.ndarray, /):
+        """
+        usage.xarray: 2
+        """
+        ...
+
+    @overload
+    def __getitem__(self, _0: slice[int, int, int], /):
+        """
+        usage.dask: 1
+        """
+        ...
+
     def __getitem__(
         self,
         _0: Union[
@@ -117,25 +160,12 @@ class CategoricalIndex:
         """
         ...
 
-    def equals(self, /, other: pandas.core.indexes.category.CategoricalIndex):
-        """
-        usage.dask: 1
-        usage.xarray: 2
-        """
-        ...
-
     def get_indexer(self, /, target: numpy.ndarray, method: None, tolerance: None):
         """
         usage.xarray: 1
         """
         ...
 
-    def reindex(self, /, target: pandas.core.indexes.base.Index):
-        """
-        usage.dask: 1
-        """
-        ...
-
     def remove_categories(self, /):
         """
         usage.dask: 1
@@ -154,6 +184,20 @@ class CategoricalIndex:
         """
         ...
 
+    @overload
+    def set_categories(self, /):
+        """
+        usage.dask: 1
+        """
+        ...
+
+    @overload
+    def set_categories(self, /, *args: Literal["v", "t"]):
+        """
+        usage.dask: 2
+        """
+        ...
+
     def set_categories(self, /, *args: Literal["v", "t"]):
         """
         usage.dask: 3
